Stan Math Library: stan::math::LDLT_alloc< R, C > Class Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | Public Attributes | List of all members
stan::math::LDLT_alloc< R, C > Class Template Reference

This object stores the actual (double typed) LDLT factorization of an Eigen::Matrix<var> along with pointers to its vari's which allow the *_ldlt functions to save memory. More...

`#include <LDLT_alloc.hpp>`

Inheritance diagram for stan::math::LDLT_alloc< R, C >:

## Public Member Functions
| LDLT_alloc ()
| LDLT_alloc (const Eigen::Matrix< var, R, C > &A)
void | compute (const Eigen::Matrix< var, R, C > &A)
| Compute the LDLT factorization and store pointers to the vari's of the matrix entries to be used when chain() is called elsewhere. More...
double | log_abs_det () const
| Compute the log(abs(det(A))). This is just a convenience function. More...
Public Member Functions inherited from stan::math::chainable_alloc
| chainable_alloc ()
virtual | ~chainable_alloc ()

## Public Attributes
size_t | N_
Eigen::LDLT< Eigen::Matrix< double, R, C > > | _ldlt
Eigen::Matrix< vari *, R, C > | _variA

## Detailed Description

### template<int R, int C>
class stan::math::LDLT_alloc< R, C >

This object stores the actual (double typed) LDLT factorization of an Eigen::Matrix<var> along with pointers to its vari's which allow the *_ldlt functions to save memory.

It is derived from a chainable_alloc object so that it is allocated on the stack but does not have a chain() function called.

This class should only be instantiated as part of an LDLT_factor object and is only used in *_ldlt functions.

Definition at line 20 of file LDLT_alloc.hpp.

## Constructor & Destructor Documentation

template<int R, int C>

stan::math::LDLT_alloc< R, C >::LDLT_alloc | ( |  | ) |
| inline

Definition at line 22 of file LDLT_alloc.hpp.

template<int R, int C>

stan::math::LDLT_alloc< R, C >::LDLT_alloc | ( | const Eigen::Matrix< var, R, C > & | A | ) |
| inlineexplicit

Definition at line 23 of file LDLT_alloc.hpp.

## Member Function Documentation

template<int R, int C>

void stan::math::LDLT_alloc< R, C >::compute | ( | const Eigen::Matrix< var, R, C > & | A | ) |
| inline

Compute the LDLT factorization and store pointers to the vari's of the matrix entries to be used when chain() is called elsewhere.

Definition at line 32 of file LDLT_alloc.hpp.

template<int R, int C>

double stan::math::LDLT_alloc< R, C >::log_abs_det | ( |  | ) | const
| inline

Compute the log(abs(det(A))). This is just a convenience function.

Definition at line 49 of file LDLT_alloc.hpp.

## Member Data Documentation

template<int R, int C>

Eigen::LDLT<Eigen::Matrix<double, R, C> > stan::math::LDLT_alloc< R, C >::_ldlt

Definition at line 54 of file LDLT_alloc.hpp.

template<int R, int C>

Eigen::Matrix<vari*, R, C> stan::math::LDLT_alloc< R, C >::_variA

Definition at line 55 of file LDLT_alloc.hpp.

template<int R, int C>

size_t stan::math::LDLT_alloc< R, C >::N_

Definition at line 53 of file LDLT_alloc.hpp.

The documentation for this class was generated from the following file:

- stan/math/rev/mat/fun/LDLT_alloc.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.